@@ -6,7 +6,8 @@ test_that("custom scalar functions translated correctly", {
     translate_sql(!!enquo(x), con = simulate_oracle())
   }
 
-  expect_equal(trans(as.character(x)), sql("CAST(`x` AS VARCHAR(255))"))
+  expect_equal(trans(as.character(x)), sql("CAST(`x` AS VARCHAR2(255))"))
+  expect_equal(trans(as.integer64(x)), sql("CAST(`x` AS NUMBER(19))"))
   expect_equal(trans(as.double(x)),    sql("CAST(`x` AS NUMBER)"))
 
 })
@@ -18,15 +19,4 @@ test_that("queries translate correctly", {
     mf %>% head() %>% sql_render(simulate_oracle()),
     sql("^SELECT [*] FROM [(]SELECT [*]\nFROM [(]`df`[)] [)] `[^`]*` WHERE ROWNUM [<][=] 6")
   )
-
-  expect_match(
-    mf %>%
-      group_by(x) %>%
-      tally %>%
-      ungroup() %>%
-      tally() %>%
-      sql_render(simulate_oracle()),
-    sql("^SELECT COUNT[(][*][)] AS `nn`\nFROM [(]SELECT `x`, COUNT[(][*][)] AS `n`\nFROM [(]`df`[)] \nGROUP BY `x`[)] `[^`]*`$")
-  )
-
 })
